@@ -1,11 +1,11 @@
 from .response_wrapper import ResponseWrap
 from .extractor import Extractor
 from .validator import Validator
-from .boot import Boot
+from .http_boot import HttpBoot
 
 __author__ = "shigebeyond"
-__version__ = "1.0.2"
-__description__ = "HttpBoot: make an easy way (yaml) to HTTP(S) API automation testing"
+__version__ = "1.0.3"
+__description__ = "HttpBoot: make an easy way (yaml) to HTTP(S) API automation testing, also support using yaml to call locust performance test"
 
 __all__ = [
     "__author__",
@@ -14,5 +14,5 @@ __all__ = [
     "ResponseWrap",
     "Extractor",
     "Validator",
-    "Boot",
+    "HttpBoot",
 ]
\ No newline at end of file
